# coding=utf-8
from __future__ import absolute_import, print_function

import os

from suanpan.objects import Context

g = Context(
    userId=os.environ.get("SP_USER_ID"),
    appId=os.environ.get("SP_APP_ID"),
    nodeId=os.environ.get("SP_NODE_ID"),
    nodeGroup=os.environ.get("SP_NODE_GROUP", "default"),
    host=os.environ.get("SP_HOST"),
    hostTls=os.environ.get("SP_HOST_TLS") in ("true", "True"),
    apiHost=os.environ.get("SP_API_HOST"),
    apiHostTls=os.environ.get("SP_API_HOST_TLS") in ("true", "True"),
    affinity=os.environ.get("SP_AFFINITY"),
    affinityTls=os.environ.get("SP_AFFINITY_TLS") in ("true", "True"),
    userIdHeaderField=os.environ.get("SP_USER_ID_HEADER_FIELD", "x-sp-user-id")
)



# coding=utf-8
from __future__ import absolute_import, print_function

from suanpan import g
from suanpan.api import requests


def getAffinityUrl(path, tls=g.affinityTls):
    host = g.affinity or g.host
    if not g.affinity and not g.host:
        raise Exception("Suanpan API call Error: affinity and host not set")
    protocol = "https" if tls else "http"
    return "{}://{}{}".format(protocol, host, path)


def get(path, *args, **kwargs):
    return requests.get(getAffinityUrl(path), *args, **kwargs)


def post(path, *args, **kwargs):
    return requests.post(getAffinityUrl(path), *args, **kwargs)


def put(path, *args, **kwargs):
    return requests.put(getAffinityUrl(path), *args, **kwargs)


def delete(path, *args, **kwargs):
    return requests.delete(getAffinityUrl(path), *args, **kwargs)
